@@ -37,10 +37,21 @@
 #include <X11/Xlib.h>
 #include <X11/Xatom.h>
 #include <gdk/gdk.h>
+#include <gdk/gdkkeysyms.h>
 #include <gdk/gdkprivate.h>
 #include <gdk/gdkx.h>
-#include <gtk/gtk.h>
+#include <gtk/gtkalignment.h>
+#include <gtk/gtkdialog.h>
+#include <gtk/gtkdnd.h>
+#include <gtk/gtkhbox.h>
+#include <gtk/gtkimage.h>
+#include <gtk/gtkmain.h>
+#include <gtk/gtkrc.h>
+#include <gtk/gtkselection.h>
+#include <gtk/gtkseparatormenuitem.h>
+#include <gtk/gtksignal.h>
 #include <math.h>
+
 #include "eel-marshal.h"
 #include "eel-marshal.c"
 
@@ -248,6 +259,8 @@ eel_gtk_window_set_initial_geometry (GtkWindow *window,
 	int screen_width, screen_height;
 
 	g_return_if_fail (GTK_IS_WINDOW (window));
+	g_return_if_fail (!(geometry_flags & EEL_GDK_WIDTH_VALUE));
+	g_return_if_fail (!(geometry_flags & EEL_GDK_HEIGHT_VALUE));
 
 	/* Setting the default size doesn't work when the window is already showing.
 	 * Someday we could make this move an already-showing window, but we don't
@@ -343,6 +356,19 @@ eel_gtk_window_set_initial_geometry_from_string (GtkWindow *window,
 	eel_gtk_window_set_initial_geometry (window, geometry_flags, left, top, width, height);
 }
 
+/**
+ * eel_truncate_text_for_menu_item:
+ * 
+ * Given an arbitrary string, returns a newly-allocated string
+ * suitable for use as a menu item label. Truncates long strings 
+ * in the middle.
+ */
+char *
+eel_truncate_text_for_menu_item (const char *text)
+{
+	return eel_str_middle_truncate (text, MAXIMUM_MENU_TITLE_LENGTH);
+}
+
 /**
  * eel_pop_up_context_menu:
  * 
@@ -436,26 +462,6 @@ eel_gtk_menu_set_item_visibility (GtkMenu *menu, int index, gboolean visible)
 	g_list_free (children);
 }
 
-GtkWidget *
-eel_gtk_menu_tool_button_get_button (GtkMenuToolButton *tool_button)
-{
-	GtkContainer *container;
-	GList *children;
-	GtkWidget *button;
-
-	g_return_val_if_fail (GTK_IS_MENU_TOOL_BUTTON (tool_button), NULL);
-
-	/* The menu tool button's button is the first child
-	 * of the child hbox. */
-	container = GTK_CONTAINER (gtk_bin_get_child (GTK_BIN (tool_button)));
-	children = gtk_container_get_children (container);
-	button = GTK_WIDGET (children->data);
-
-	g_list_free (children);
-
-	return button;
-}
-
 gboolean
 eel_point_in_allocation (const GtkAllocation *allocation,
 			      int x, int y)
@@ -594,13 +600,13 @@ static void
 while_realized_disconnecter (GtkObject *object,
 			     RealizeDisconnectInfo *info)
 {
-	g_assert (GTK_IS_OBJECT (object));
-	g_assert (info != NULL);
-	g_assert (GTK_IS_OBJECT (info->object));
-	g_assert (info->object_destroy_handler != 0);
-	g_assert (info->object_destroy_handler != 0);
-	g_assert (info->realized_widget_destroy_handler != 0);
-	g_assert (info->realized_widget_unrealized_handler != 0);
+	g_return_if_fail (GTK_IS_OBJECT (object));
+	g_return_if_fail (info != NULL);
+	g_return_if_fail (GTK_IS_OBJECT (info->object));
+	g_return_if_fail (info->object_destroy_handler != 0);
+	g_return_if_fail (info->object_destroy_handler != 0);
+	g_return_if_fail (info->realized_widget_destroy_handler != 0);
+	g_return_if_fail (info->realized_widget_unrealized_handler != 0);
 
  	g_signal_handler_disconnect (info->object, info->object_destroy_handler);
  	g_signal_handler_disconnect (info->object, info->signal_handler);
